[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --everything-is-local
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NOME](https://git-scm.com/docs/git/pt_BR#_nome)
    * [RESUMO](https://git-scm.com/docs/git/pt_BR#_resumo)
    * [DESCRIÇÃO](https://git-scm.com/docs/git/pt_BR#_descri%c3%a7%c3%a3o)
    * [OPÇÕES](https://git-scm.com/docs/git/pt_BR#_op%c3%a7%c3%b5es)
    * [OS COMANDOS DO GIT](https://git-scm.com/docs/git/pt_BR#_os_comandos_do_git)
    * [Comandos de alto nível (porcelana)](https://git-scm.com/docs/git/pt_BR#_comandos_de_alto_n%c3%advel_porcelana)
    * [Comandos de baixo nível (encanamento plumbing)](https://git-scm.com/docs/git/pt_BR#_comandos_de_baixo_n%c3%advel_encanamento_plumbing)
    * [Guias](https://git-scm.com/docs/git/pt_BR#_guias)
    * [As interfaces do repositório, do comando e do arquivo](https://git-scm.com/docs/git/pt_BR#_as_interfaces_do_reposit%c3%b3rio_do_comando_e_do_arquivo)
    * [Formatos dos arquivos, protocolos e outras interfaces do desenvolvedor](https://git-scm.com/docs/git/pt_BR#_formatos_dos_arquivos_protocolos_e_outras_interfaces_do_desenvolvedor)
    * [Mecanismo de Configuração](https://git-scm.com/docs/git/pt_BR#_mecanismo_de_configura%c3%a7%c3%a3o)
    * [Terminologia do Identificador](https://git-scm.com/docs/git/pt_BR#_terminologia_do_identificador)
    * [Identificadores Simbólicos](https://git-scm.com/docs/git/pt_BR#_identificadores_simb%c3%b3licos)
    * [A Estrutura dos Arquivos/Diretórios](https://git-scm.com/docs/git/pt_BR#_a_estrutura_dos_arquivosdiret%c3%b3rios)
    * [Terminologia](https://git-scm.com/docs/git/pt_BR#_terminologia)
    * [As Variáveis do Ambiente](https://git-scm.com/docs/git/pt_BR#_as_vari%c3%a1veis_do_ambiente)
    * [Discussão](https://git-scm.com/docs/git/pt_BR#_discuss%c3%a3o)
    * [SEGURANÇA](https://git-scm.com/docs/git/pt_BR#_seguran%c3%a7a)
    * [DOCUMENTAÇÃO ADICIONAL](https://git-scm.com/docs/git/pt_BR#_documenta%c3%a7%c3%a3o_adicional)
    * [Autores](https://git-scm.com/docs/git/pt_BR#_autores)
    * [Reportando um Erro](https://git-scm.com/docs/git/pt_BR#_reportando_um_erro)
    * [VEJA TAMBÉM](https://git-scm.com/docs/git/pt_BR#_veja_tamb%c3%a9m)
    * [GIT](https://git-scm.com/docs/git/pt_BR#_git)


[ Português (Brasil) ▾](https://git-scm.com/docs/git/pt_BR)
Localized versions of **git** manual
  1. [English ](https://git-scm.com/docs/git)
  2. [Deutsch ](https://git-scm.com/docs/git/de)
  3. [Español ](https://git-scm.com/docs/git/es)
  4. [Français ](https://git-scm.com/docs/git/fr)
  5. [Português (Brasil) ](https://git-scm.com/docs/git/pt_BR)
  6. [Svenska ](https://git-scm.com/docs/git/sv)
  7. [українська мова ](https://git-scm.com/docs/git/uk)
  8. [简体中文 ](https://git-scm.com/docs/git/zh_HANS-CN)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/git/pt_BR)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git/pt_BR)
  * [ config ](https://git-scm.com/docs/git-config/pt_BR)
  * [ help ](https://git-scm.com/docs/git-help/pt_BR)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport/pt_BR)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init/pt_BR)
  * [ clone ](https://git-scm.com/docs/git-clone/pt_BR)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add/pt_BR)
  * [ status ](https://git-scm.com/docs/git-status/pt_BR)
  * [ diff ](https://git-scm.com/docs/git-diff/pt_BR)
  * [ commit ](https://git-scm.com/docs/git-commit/pt_BR)
  * [ notes ](https://git-scm.com/docs/git-notes/pt_BR)
  * [ restore ](https://git-scm.com/docs/git-restore/pt_BR)
  * [ reset ](https://git-scm.com/docs/git-reset/pt_BR)
  * [ rm ](https://git-scm.com/docs/git-rm/pt_BR)
  * [ mv ](https://git-scm.com/docs/git-mv/pt_BR)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch/pt_BR)
  * [ checkout ](https://git-scm.com/docs/git-checkout/pt_BR)
  * [ switch ](https://git-scm.com/docs/git-switch/pt_BR)
  * [ merge ](https://git-scm.com/docs/git-merge/pt_BR)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool/pt_BR)
  * [ log ](https://git-scm.com/docs/git-log/pt_BR)
  * [ stash ](https://git-scm.com/docs/git-stash/pt_BR)
  * [ tag ](https://git-scm.com/docs/git-tag/pt_BR)
  * [ worktree ](https://git-scm.com/docs/git-worktree/pt_BR)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch/pt_BR)
  * [ pull ](https://git-scm.com/docs/git-pull/pt_BR)
  * [ push ](https://git-scm.com/docs/git-push/pt_BR)
  * [ remote ](https://git-scm.com/docs/git-remote/pt_BR)
  * [ submodule ](https://git-scm.com/docs/git-submodule/pt_BR)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show/pt_BR)
  * [ log ](https://git-scm.com/docs/git-log/pt_BR)
  * [ diff ](https://git-scm.com/docs/git-diff/pt_BR)
  * [ difftool ](https://git-scm.com/docs/git-difftool/pt_BR)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff/pt_BR)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog/pt_BR)
  * [ describe ](https://git-scm.com/docs/git-describe/pt_BR)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply/pt_BR)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick/pt_BR)
  * [ diff ](https://git-scm.com/docs/git-diff/pt_BR)
  * [ rebase ](https://git-scm.com/docs/git-rebase/pt_BR)
  * [ revert ](https://git-scm.com/docs/git-revert/pt_BR)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect/pt_BR)
  * [ blame ](https://git-scm.com/docs/git-blame/pt_BR)
  * [ grep ](https://git-scm.com/docs/git-grep/pt_BR)


### Email
  * [ am ](https://git-scm.com/docs/git-am/pt_BR)
  * [ apply ](https://git-scm.com/docs/git-apply/pt_BR)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send/pt_BR)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch/pt_BR)
  * [ send-email ](https://git-scm.com/docs/git-send-email/pt_BR)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull/pt_BR)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn/pt_BR)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import/pt_BR)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon/pt_BR)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info/pt_BR)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary/pt_BR)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore/pt_BR)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean/pt_BR)
  * [ gc ](https://git-scm.com/docs/git-gc/pt_BR)
  * [ fsck ](https://git-scm.com/docs/git-fsck/pt_BR)
  * [ reflog ](https://git-scm.com/docs/git-reflog/pt_BR)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch/pt_BR)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb/pt_BR)
  * [ archive ](https://git-scm.com/docs/git-archive/pt_BR)
  * [ bundle ](https://git-scm.com/docs/git-bundle/pt_BR)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file/pt_BR)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore/pt_BR)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index/pt_BR)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree/pt_BR)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects/pt_BR)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index/pt_BR)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref/pt_BR)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object/pt_BR)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files/pt_BR)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree/pt_BR)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base/pt_BR)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree/pt_BR)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list/pt_BR)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse/pt_BR)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref/pt_BR)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref/pt_BR)
  * [ update-index ](https://git-scm.com/docs/git-update-index/pt_BR)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref/pt_BR)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack/pt_BR)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree/pt_BR)


[ Latest version ▾ ](https://git-scm.com/docs/git/pt_BR) git last updated in 2.53.0
Changes in the **git** manual
  1. [2.53.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2026-02-02_ ](https://git-scm.com/docs/git/2.53.0)
  2. [2.52.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-11-17_ ](https://git-scm.com/docs/git/2.52.0)
  3. 2.51.2 no changes
  4. [2.51.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-10-15_ ](https://git-scm.com/docs/git/2.51.1)
  5. 2.50.1 → 2.51.0 no changes
  6. [2.50.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-06-16_ ](https://git-scm.com/docs/git/2.50.0)
  7. 2.49.1 no changes
  8. [2.49.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-03-14_ ](https://git-scm.com/docs/git/2.49.0)
  9. 2.48.1 → 2.48.2 no changes
  10. [2.48.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-01-10_ ](https://git-scm.com/docs/git/2.48.0)
  11. 2.47.1 → 2.47.3 no changes
  12. [2.47.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-10-06_ ](https://git-scm.com/docs/git/2.47.0)
  13. 2.46.1 → 2.46.4 no changes
  14. [2.46.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-07-29_ ](https://git-scm.com/docs/git/2.46.0)
  15. 2.45.2 → 2.45.4 no changes
  16. [2.45.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git/2.45.1)
  17. [2.45.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git/2.45.0)
  18. 2.44.2 → 2.44.4 no changes
  19. [2.44.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.44.1)
  20. [2.44.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-23_ ](https://git-scm.com/docs/git/2.44.0)
  21. 2.43.5 → 2.43.7 no changes
  22. [2.43.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.43.4)
  23. 2.43.2 → 2.43.3 no changes
  24. [2.43.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-09_ ](https://git-scm.com/docs/git/2.43.1)
  25. [2.43.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-20_ ](https://git-scm.com/docs/git/2.43.0)
  26. 2.42.3 → 2.42.4 no changes
  27. [2.42.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.42.2)
  28. [2.42.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-02_ ](https://git-scm.com/docs/git/2.42.1)
  29. [2.42.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-08-21_ ](https://git-scm.com/docs/git/2.42.0)
  30. 2.41.2 → 2.41.3 no changes
  31. [2.41.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.41.1)
  32. [2.41.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-06-01_ ](https://git-scm.com/docs/git/2.41.0)
  33. 2.40.3 → 2.40.4 no changes
  34. [2.40.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.40.2)
  35. 2.40.1 no changes
  36. 2.40.0 no changes
  37. 2.39.5 no changes
  38. [2.39.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.39.4)
  39. 2.39.1 → 2.39.3 no changes
  40. [2.39.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-12_ ](https://git-scm.com/docs/git/2.39.0)
  41. 2.38.3 → 2.38.5 no changes
  42. [2.38.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-11_ ](https://git-scm.com/docs/git/2.38.2)
  43. 2.38.1 no changes
  44. [2.38.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-10-02_ ](https://git-scm.com/docs/git/2.38.0)
  45. 2.37.3 → 2.37.7 no changes
  46. [2.37.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-08-11_ ](https://git-scm.com/docs/git/2.37.2)
  47. 2.37.1 no changes
  48. [2.37.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-06-27_ ](https://git-scm.com/docs/git/2.37.0)
  49. 2.36.1 → 2.36.6 no changes
  50. [2.36.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-04-18_ ](https://git-scm.com/docs/git/2.36.0)
  51. 2.35.1 → 2.35.8 no changes
  52. [2.35.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-01-24_ ](https://git-scm.com/docs/git/2.35.0)
  53. 2.34.1 → 2.34.8 no changes
  54. [2.34.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-11-15_ ](https://git-scm.com/docs/git/2.34.0)
  55. 2.33.3 → 2.33.8 no changes
  56. [2.33.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-03-23_ ](https://git-scm.com/docs/git/2.33.2)
  57. [2.33.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-10-12_ ](https://git-scm.com/docs/git/2.33.1)
  58. 2.32.1 → 2.33.0 no changes
  59. [2.32.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-06-06_ ](https://git-scm.com/docs/git/2.32.0)
  60. 2.31.1 → 2.31.8 no changes
  61. [2.31.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-03-15_ ](https://git-scm.com/docs/git/2.31.0)
  62. 2.30.1 → 2.30.9 no changes
  63. [2.30.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-12-27_ ](https://git-scm.com/docs/git/2.30.0)
  64. 2.29.1 → 2.29.3 no changes
  65. [2.29.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-10-19_ ](https://git-scm.com/docs/git/2.29.0)
  66. 2.28.1 no changes
  67. [2.28.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-07-27_ ](https://git-scm.com/docs/git/2.28.0)
  68. 2.27.1 no changes
  69. [2.27.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-06-01_ ](https://git-scm.com/docs/git/2.27.0)
  70. 2.26.1 → 2.26.3 no changes
  71. [2.26.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-03-22_ ](https://git-scm.com/docs/git/2.26.0)
  72. 2.25.2 → 2.25.5 no changes
  73. [2.25.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-02-17_ ](https://git-scm.com/docs/git/2.25.1)
  74. [2.25.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-01-13_ ](https://git-scm.com/docs/git/2.25.0)
  75. 2.23.1 → 2.24.4 no changes
  76. [2.23.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-16_ ](https://git-scm.com/docs/git/2.23.0)
  77. 2.22.2 → 2.22.5 no changes
  78. [2.22.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-11_ ](https://git-scm.com/docs/git/2.22.1)
  79. [2.22.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-06-07_ ](https://git-scm.com/docs/git/2.22.0)
  80. 2.20.1 → 2.21.4 no changes
  81. [2.20.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-12-09_ ](https://git-scm.com/docs/git/2.20.0)
  82. 2.19.3 → 2.19.6 no changes
  83. [2.19.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-11-21_ ](https://git-scm.com/docs/git/2.19.2)
  84. 2.19.1 no changes
  85. [2.19.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-09-10_ ](https://git-scm.com/docs/git/2.19.0)
  86. 2.18.1 → 2.18.5 no changes
  87. [2.18.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-06-21_ ](https://git-scm.com/docs/git/2.18.0)
  88. 2.17.1 → 2.17.6 no changes
  89. [2.17.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-04-02_ ](https://git-scm.com/docs/git/2.17.0)
  90. [2.16.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.16.6)
  91. [2.15.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.15.4)
  92. [2.14.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.14.6)
  93. 2.13.7 no changes
  94. [2.12.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.12.5)
  95. [2.11.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.11.4)
  96. [2.10.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.10.5)
  97. [2.9.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.9.5)
  98. [2.8.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.8.6)
  99. [2.7.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.7.6)
  100. [2.6.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.6.7)
  101. [2.5.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.5.6)
  102. [2.4.12 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.4.12)
  103. [2.3.10 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-28_ ](https://git-scm.com/docs/git/2.3.10)
  104. [2.2.3 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-04_ ](https://git-scm.com/docs/git/2.2.3)
  105. [2.1.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git/2.1.4)
  106. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/git/pt_BR#_nome)NOME
git - o monitor estúpido de conteúdo
##  [](https://git-scm.com/docs/git/pt_BR#_resumo)RESUMO
```
_git_ [-v | --version] [-h | --help] [-C <path>] [-c <name>=<value>]
    [--exec-path[=<path>]] [--html-path] [--man-path] [--info-path]
    [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--no-lazy-fetch]
    [--no-optional-locks] [--no-advice] [--bare] [--git-dir=<path>]
    [--work-tree=<path>] [--namespace=<name>] [--config-env=<name>=<envvar>]
    <command> [<args>]
```

##  [](https://git-scm.com/docs/git/pt_BR#_descri%C3%A7%C3%A3o)DESCRIÇÃO
O Git é um sistema de controle de revisão distribuído, rápido, escalável e com um conjunto de comandos incomumente rico que oferece operações de alto nível e acesso completo aos seus recursos.
Consulte [gittutorial[7]](https://git-scm.com/docs/gittutorial/pt_BR) para começar e, em seguida, [giteveryday[7]](https://git-scm.com/docs/giteveryday/pt_BR) para obter um conjunto mínimo útil de comandos. O [O manual do usuário do Git](https://git-scm.com/docs/user-manual/pt_BR) tem uma introdução mais aprofundada.
Após dominar os conceitos básicos, você pode voltar a esta página para saber quais comandos o Git oferece. Você pode saber mais sobre comandos individuais do Git com o comando _git help_. A página do manual [gitcli[7]](https://git-scm.com/docs/gitcli/pt_BR) oferece uma visão geral da sintaxe do comando de linha de comando.
Uma cópia formatada e com hiperlink da documentação mais recente do Git pode ser visualizada em <https://git.github.io/htmldocs/git.html> ou <https://git-scm.com/docs>.
##  [](https://git-scm.com/docs/git/pt_BR#_op%C3%A7%C3%B5es)OPÇÕES

[](https://git-scm.com/docs/git/pt_BR#git--v)-v


[](https://git-scm.com/docs/git/pt_BR#git---version)--version

Imprime a versão do pacote Git exibindo a sua origem.
Esta opção é convertida internamente para `git` `version` ... e aceita as mesmas opções que o comando [git-version[1]](https://git-scm.com/docs/git-version/pt_BR). Se a opção `--help` também for usada, ela tem precedência sobre a opção `--version`.

[](https://git-scm.com/docs/git/pt_BR#git--h)-h


[](https://git-scm.com/docs/git/pt_BR#git---help)--help

Imprime a sinopse e uma lista dos comandos mais usados. Caso a opção `--all` ou `-a` seja usada, todos os comandos disponíveis serão impressos. Caso um comando Git seja informado, esta opção exibirá a página do manual deste comando.
Outras opções estão disponíveis para controlar como a página do manual é exibida. Para mais informações, consulte [git-help[1]](https://git-scm.com/docs/git-help/pt_BR), pois o comando `git` `--help` ... é convertido internamente em `git` `help` ....

[](https://git-scm.com/docs/git/pt_BR#git--Ccaminho) [](https://git-scm.com/docs/git/pt_BR#git--Cltcaminhogt)-C <caminho>

Executar como se o git tivesse sido iniciado em _< caminho>_ em vez de no diretório de trabalho atual. Quando várias opções `-C` são usadas, cada `-C` _< caminho>_ não absoluto subsequente é interpretado em relação ao `-C` _< caminho>_ anterior. Se o _< caminho>_ estiver presente, mas vazio, por exemplo, `-C` `""`, o diretório de trabalho atual não será alterado.
Esta opção afeta as opções que esperam o nome do caminho, como `--git-dir` e `--work-tree`, pois as suas interpretações dos nomes dos caminhos seriam feitas em relação ao diretório de trabalho causado pela opção `-C`. Como, por exemplo, as seguintes invocações são equivalentes:
```
git --git-dir=a.git --work-tree=b -C c status
git --git-dir=c/a.git --work-tree=c/b status
```


[](https://git-scm.com/docs/git/pt_BR#git--cnomevalor) [](https://git-scm.com/docs/git/pt_BR#git--cltnomegtltvalorgt)-c <nome>=<valor>

Repassa um parâmetro de configuração para o comando. O valor fornecido substituirá os valores dos arquivos de configuração. O <nome> é esperado no mesmo formato listado através do comando _git config_ (subchaves separadas por pontos).
Note que ao omitir `=` no comando `git` `-c` `foo.bar` ... é permitido e define `foo.bar` com o valor booleano verdadeiro (assim como`[foo]bar` faria em um arquivo de configuração). Incluindo os iguais, porém com um valor vazio (como `git` `-c` `foo.bar=` ...) define `foo.bar` para a string vazia que `git` `config` `--type=bool` converterá para `false`.

[](https://git-scm.com/docs/git/pt_BR#git---config-envnomeenvvar) [](https://git-scm.com/docs/git/pt_BR#git---config-envltnomegtltenvvargt)--config-env=<nome>=<envvar>

Assim como `-c` _< nome>_`=`_< valor>_, atribui à variável de configuração _< nome>_ um valor, onde <envvar> é o nome de uma variável de ambiente de onde se obtém o valor. Ao contrário da opção `-c`, não há atalho para definir diretamente o valor como uma string vazia; em vez disso, a própria variável de ambiente deve ser definida como uma string vazia. Ocorrerá um erro se a _< envvar>_ não existir no ambiente. O _< envvar>_ não pode conter um sinal de igual para evitar ambiguidade com _< nome>_ que contenha um.
Isso é útil para casos onde você deseja passar opções de configuração transitórias para o git, porém está fazendo isso em sistemas operacionais onde outros processos possam ser capazes de ler a sua linha de comando (`/proc/self/cmdline` por exemplo), mas não o seu ambiente (`/proc/self/Environment` por exemplo). Este é comportamento normal no Linux, mas pode não estar no seu sistema.
Observe que isso pode adicionar segurança para variáveis como `http.extraHeader` onde as informações confidenciais fazem parte do valor, mas não `url.`_< base>_`.insteadOf` por exemplo onde as informações confidenciais podem fazer parte da chave.

[](https://git-scm.com/docs/git/pt_BR#git---exec-pathcaminho) [](https://git-scm.com/docs/git/pt_BR#git---exec-pathltcaminhogt)--exec-path[=<caminho>]

O caminho para o local onde os programas principais do Git estão instalados. Isso também pode ser controlado pela configuração da variável de ambiente `GIT_EXEC_PATH`. Se nenhum caminho for fornecido, o _git_ imprimirá a configuração atual e encerrará.

[](https://git-scm.com/docs/git/pt_BR#git---html-path)--html-path

Imprima o caminho, sem barra, onde a documentação HTML do Git está instalada e encerre.

[](https://git-scm.com/docs/git/pt_BR#git---man-path)--man-path

Imprima o manpath (consulte `man`(`1`)) para as páginas do manual desta versão do Git e encerre.

[](https://git-scm.com/docs/git/pt_BR#git---info-path)--info-path

Imprima o caminho onde os arquivos Info que documentam esta versão do Git estão instalados e encerre.

[](https://git-scm.com/docs/git/pt_BR#git--p)-p


[](https://git-scm.com/docs/git/pt_BR#git---paginate)--paginate

Canalize toda a saída para _less_ (ou, se definido, `$PAGER`) se a saída predefinida for um terminal. Isso substitui as opções de configuração `pager.`_< cmd>_ (consulte a seção "Mecanismo de configuração" abaixo).

[](https://git-scm.com/docs/git/pt_BR#git--P)-P


[](https://git-scm.com/docs/git/pt_BR#git---no-pager)--no-pager

Não canalize a saída do Git para um pager.

[](https://git-scm.com/docs/git/pt_BR#git---git-dircaminho) [](https://git-scm.com/docs/git/pt_BR#git---git-dirltcaminhogt)--git-dir=<caminho>

Define o caminho para o repositório (o diretório ".git"). Isso também pode ser controlado pela configuração da variável de ambiente `GIT_DIR`. Pode ser um caminho absoluto ou relativo ao diretório de trabalho atual.
Especificar o local do diretório _.git_ usando essa opção (ou a variável de ambiente `GIT_DIR`) desativa a descoberta do repositório que tenta encontrar um diretório com o subdiretório _.git_ (que é como o repositório e o nível superior da árvore de trabalho são descobertos) e informa ao Git que você está no nível mais alto da árvore de trabalho. Se você não estiver no diretório do cume da árvore de trabalho, deverá informar ao Git onde está o nível superior da árvore de trabalho, com a opção `--work-tree=`_< caminho>_ (ou a variável de ambiente `GIT_WORK_TREE`)
Caso queira executar o git como se tivesse sido iniciado em _< caminho>_, utilize `git` `-C` _< caminho>_.

[](https://git-scm.com/docs/git/pt_BR#git---work-treecaminho) [](https://git-scm.com/docs/git/pt_BR#git---work-treeltcaminhogt)--work-tree=<caminho>

Defina o caminho para a árvore de trabalho. Pode ser um caminho absoluto ou um caminho relativo ao diretório de trabalho atual. Isso também pode ser controlado definindo a variável de ambiente `GIT_WORK_TREE` e a variável de configuração `core.worktree` (consulte `core.worktree` do comando [git-config[1]](https://git-scm.com/docs/git-config/pt_BR) para obter informações mais detalhadas).

[](https://git-scm.com/docs/git/pt_BR#git---namespacecaminho) [](https://git-scm.com/docs/git/pt_BR#git---namespaceltcaminhogt)--namespace=<caminho>

Define o espaços de nomes do Git. Para mais detalhes consulte [gitnamespaces[7]](https://git-scm.com/docs/gitnamespaces/pt_BR). Equivale a definir a variável de ambiente `GIT_NAMESPACE`.

[](https://git-scm.com/docs/git/pt_BR#git---bare)--bare

Trate o repositório como um repositório simples. Se o ambiente `GIT_DIR` não estiver definido, ele será definido como o diretório de trabalho atual.

[](https://git-scm.com/docs/git/pt_BR#git---no-replace-objects)--no-replace-objects

Do not use replacement refs to replace Git objects. This is equivalent to exporting the `GIT_NO_REPLACE_OBJECTS` environment variable with any value. See [git-replace[1]](https://git-scm.com/docs/git-replace/pt_BR) for more information.

[](https://git-scm.com/docs/git/pt_BR#git---no-lazy-fetch)--no-lazy-fetch

Do not fetch missing objects from the promisor remote on demand. Useful together with `git` `cat-file` `-e` _< object>_ to see if the object is locally available. This is equivalent to setting the `GIT_NO_LAZY_FETCH` environment variable to `1`.

[](https://git-scm.com/docs/git/pt_BR#git---no-optional-locks)--no-optional-locks

Não execute operações opcionais que exijam bloqueios. Isso é equivalente que definir o `GIT_OPTIONAL_LOCKS` como `0`.

[](https://git-scm.com/docs/git/pt_BR#git---no-advice)--no-advice

Disable all advice hints from being printed.

[](https://git-scm.com/docs/git/pt_BR#git---literal-pathspecs)--literal-pathspecs

Trate os _pathpecs_ literalmente (ou seja, sem _globbing_ , sem truques para o _pathpec_). Isso é o mesmo que definir a variável de ambiente `GIT_LITERAL_PATHSPECS` como `1`.

[](https://git-scm.com/docs/git/pt_BR#git---glob-pathspecs)--glob-pathspecs

Adicione a magia _glob_ para todos os _pathspec_. É como definir a variável de ambiente `GIT_GLOB_PATHSPECS` como `1`. A desativação do caractere curinga nos pathspecs individuais podem ser feitos utilizando a mágica do pathspec ": (literal)"

[](https://git-scm.com/docs/git/pt_BR#git---noglob-pathspecs)--noglob-pathspecs

Adicione a magia _literal_ a todos os "pathspec". É equivalente a definir a variável de ambiente `GIT_NOGLOB_PATHSPECS` para `1`. A ativação dos caracteres curinga nos "pathspecs" individuais podem ser feitos utilizando a mágica do pathspec ":(glob)"

[](https://git-scm.com/docs/git/pt_BR#git---icase-pathspecs)--icase-pathspecs

Adicione a magia _icase_ em todos os pathspec. É como definir a variável de ambiente `GIT_ICASE_PATHSPECS` como `1`.

[](https://git-scm.com/docs/git/pt_BR#git---list-cmdsgrupogrupo) [](https://git-scm.com/docs/git/pt_BR#git---list-cmdsltgrupogtltgrupogt82308203)--list-cmds=<grupo>[,<grupo>…​]

List commands by group. This is an internal/experimental option and may change or be removed in the future. Supported groups are: builtins, parseopt (builtin commands that use parse-options), deprecated (deprecated builtins), main (all commands in libexec directory), others (all other commands in `$PATH` that have git- prefix), list-<category> (see categories in command-list.txt), nohelpers (exclude helper commands), alias and config (retrieve command list from config variable completion.commands)

[](https://git-scm.com/docs/git/pt_BR#git---attr-sourcetree-ish) [](https://git-scm.com/docs/git/pt_BR#git---attr-sourcelttree-ishgt)--attr-source=<tree-ish>

Leia o gitattributes do <tree-ish> em vez da árvore de trabalho. Consulte [gitattributes[5]](https://git-scm.com/docs/gitattributes/pt_BR). Isso é equivalente a definir a variável de ambiente `GIT_ATTR_SOURCE`.
##  [](https://git-scm.com/docs/git/pt_BR#_os_comandos_do_git)OS COMANDOS DO GIT
Dividimos o Git em comandos de alto nível ("porcelana") e de baixo nível ("encanamento").
##  [](https://git-scm.com/docs/git/pt_BR#_comandos_de_alto_n%C3%ADvel_porcelana)Comandos de alto nível (porcelana)
Separamos os comandos porcelana nos comandos principais e em alguns utilitários auxiliares do usuário.
###  [](https://git-scm.com/docs/git/pt_BR#_os_principais_comandos_porcelana)Os principais comandos porcelana
Warning |  Missing `pt_BR/{build_dir}/cmds-mainporcelain.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/pt_BR#_comandos_auxiliares)Comandos Auxiliares
Manipuladores:
Warning |  Missing `pt_BR/{build_dir}/cmds-ancillarymanipulators.adoc` See original version for this content.
---|---
Interrogadores:
Warning |  Missing `pt_BR/{build_dir}/cmds-ancillaryinterrogators.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/pt_BR#_interagindo_com_os_outros)Interagindo com os outros
Estes comandos são para interagir com um SCM externo e com as outras pessoas através de patch por e-mail.
Warning |  Missing `pt_BR/{build_dir}/cmds-foreignscminterface.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/pt_BR#_redefina_restaure_e_reverta)Redefina, restaure e reverta
Existem três comandos com nomes semelhantes: `git` `reset`, `git` `restore` e o `git` `revert`.
  * [git-revert[1]](https://git-scm.com/docs/git-revert/pt_BR) trata de fazer um novo commit que reverte as alterações feitas por outros commit.
  * [git-restore[1]](https://git-scm.com/docs/git-restore/pt_BR) trata da restauração dos arquivos na árvore de trabalho do índice ou de outro commit. Este comando não atualiza o seu ramo. O comando também pode ser usado para restaurar os arquivos no índice do outro commit.
  * [git-reset[1]](https://git-scm.com/docs/git-reset/pt_BR) trata da atualização do seu ramo, movendo o topo para adicionar ou remover os commits do ramo. Esta operação altera o histórico do commit.
O comando `git` `reset` também pode ser usado para restaurar o índice, sobrepondo com `git` `restore`.


##  [](https://git-scm.com/docs/git/pt_BR#_comandos_de_baixo_n%C3%ADvel_encanamento_plumbing)Comandos de baixo nível (encanamento _plumbing_)
Embora o Git inclua a sua própria camada de porcelana, os seus comandos de baixo nível são suficientes para dar suporte ao desenvolvimento de porcelanas alternativas. Os desenvolvedores de tais porcelanas podem começar lendo sobre os comando [git-update-index[1]](https://git-scm.com/docs/git-update-index/pt_BR) e [git-read-tree[1]](https://git-scm.com/docs/git-read-tree/pt_BR).
A interface (entrada, saída, conjunto de opções e a semântica) desses comandos de baixo nível deve ser muito mais estável do que a dos comandos no nível porcelana, porque estes comandos são destinados principalmente para utilização com scripts. A interface dos comandos porcelana, por outro lado, está sujeita a alterações para melhorar a experiência do usuário final.
A descrição a seguir divide os comandos de baixo nível em comandos que manipulam os objetos (no repositório, índice e árvore de trabalho), comandos que interrogam, comparam objetos, comandos que movem objetos e suas referências entre os repositórios.
###  [](https://git-scm.com/docs/git/pt_BR#_comandos_de_manipula%C3%A7%C3%A3o)Comandos de manipulação
Warning |  Missing `pt_BR/{build_dir}/cmds-plumbingmanipulators.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/pt_BR#_comandos_de_interroga%C3%A7%C3%A3o)Comandos de interrogação
Warning |  Missing `pt_BR/{build_dir}/cmds-plumbinginterrogators.adoc` See original version for this content.
---|---
Em geral, os comandos de interrogação não tocam nos arquivos da árvore de trabalho.
###  [](https://git-scm.com/docs/git/pt_BR#_sincronizando_os_reposit%C3%B3rios)Sincronizando os repositórios
Warning |  Missing `pt_BR/{build_dir}/cmds-synchingrepositories.adoc` See original version for this content.
---|---
A seguir, são apresentados os comandos auxiliares utilizados acima; os usuários finais normalmente não os utilizam diretamente.
Warning |  Missing `pt_BR/{build_dir}/cmds-synchelpers.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/pt_BR#_comandos_auxiliares_internos)Comandos auxiliares internos
Estes são comandos auxiliares internos usados por outros comandos; os usuários finais normalmente não os utilizam diretamente.
Warning |  Missing `pt_BR/{build_dir}/cmds-purehelpers.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/pt_BR#_guias)Guias
As páginas da documentação a seguir são os guias sobre os conceitos do Git.
Warning |  Missing `pt_BR/{build_dir}/cmds-guide.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/pt_BR#_as_interfaces_do_reposit%C3%B3rio_do_comando_e_do_arquivo)As interfaces do repositório, do comando e do arquivo
Esta documentação discute as interfaces do repositório e os comandos com as quais os usuários devem interagir diretamente. Consulte `--user-formats` em [git-help[1]](https://git-scm.com/docs/git-help/pt_BR) para obter mais detalhes sobre os critérios.
Warning |  Missing `pt_BR/{build_dir}/cmds-userinterfaces.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/pt_BR#_formatos_dos_arquivos_protocolos_e_outras_interfaces_do_desenvolvedor)Formatos dos arquivos, protocolos e outras interfaces do desenvolvedor
Esta documentação aborda os formatos dos arquivos, uma abordagem geral dos protocolos e das outras interfaces do desenvolvedor git. Consulte `--developer-interfaces` em [git-help[1]](https://git-scm.com/docs/git-help/pt_BR).
Warning |  Missing `pt_BR/{build_dir}/cmds-developerinterfaces.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/pt_BR#_mecanismo_de_configura%C3%A7%C3%A3o)Mecanismo de Configuração
O Git usa um formato de texto simples para armazenar personalizações que são por repositório e por usuário. Este arquivo de configuração pode ter a seguinte aparência:
```
#
# Os caracteres '#' ou ';' indicam um comentário.
#

; variáveis principais
[core]
	; Não confie nos modos dos arquivos
	filemode = false

; identidade do usuário
[user]
	name = "Junio C Hamano"
	email = "gitster@pobox.com"
```

Vários comandos leem o arquivo de configuração e ajustam a sua operação conforme seja necessário. Consulte o comando [git-config[1]](https://git-scm.com/docs/git-config/pt_BR) para obter uma lista e mais detalhes sobre o mecanismo de configuração.
##  [](https://git-scm.com/docs/git/pt_BR#_terminologia_do_identificador)Terminologia do Identificador

[](https://git-scm.com/docs/git/pt_BR#git-objeto) [](https://git-scm.com/docs/git/pt_BR#git-ltobjetogt)<objeto>

Indica o nome do objeto para qualquer tipo de objeto.

[](https://git-scm.com/docs/git/pt_BR#git-blob) [](https://git-scm.com/docs/git/pt_BR#git-ltblobgt)<blob>

Indica um nome de um objeto bolha.

[](https://git-scm.com/docs/git/pt_BR#git-rvore) [](https://git-scm.com/docs/git/pt_BR#git-ltrvoregt)<árvore>

Indica um nome de um objeto árvore.

[](https://git-scm.com/docs/git/pt_BR#git-commit) [](https://git-scm.com/docs/git/pt_BR#git-ltcommitgt)<commit>

Indica um nome de um objeto commit.

[](https://git-scm.com/docs/git/pt_BR#git-tree-ish) [](https://git-scm.com/docs/git/pt_BR#git-lttree-ishgt)<tree-ish>

Indica um nome do objeto da árvore, commit ou as etiquetas. Um comando que recebe um argumento <tree-ish> deseja operar num objeto _< ´árvore>_, mas remove a referência automaticamente nos objetos _< commit>_ e _< etiqueta>_ que apontam para uma _< árvore>_.

[](https://git-scm.com/docs/git/pt_BR#git-commit-ish) [](https://git-scm.com/docs/git/pt_BR#git-ltcommit-ishgt)<commit-ish>

Indica um nome da etiqueta do objeto ou do commit. Um comando que recebe um argumento _< commit-ish>_ deseja operar num objeto _< commit>_, mas remove a referência automaticamente nos objetos _< etiqueta>_ que apontam para um _< commit>_.

[](https://git-scm.com/docs/git/pt_BR#git-tipo) [](https://git-scm.com/docs/git/pt_BR#git-lttipogt)<tipo>

Indica que é necessário um tipo de objeto. Atualmente é um dos seguintes: `blob`, `tree`, `commit` ou `tag`.

[](https://git-scm.com/docs/git/pt_BR#git-arquivo) [](https://git-scm.com/docs/git/pt_BR#git-ltarquivogt)<arquivo>

Indica um nome do arquivo - quase sempre em relação à raiz da estrutura da árvore que o `GIT_INDEX_FILE` descreve.
##  [](https://git-scm.com/docs/git/pt_BR#_identificadores_simb%C3%B3licos)Identificadores Simbólicos
Qualquer comando Git que aceite qualquer <objeto> também pode utilizar a seguinte notação simbólica:

[](https://git-scm.com/docs/git/pt_BR#git-HEAD)HEAD

indica o cabeçalho do ramo atual.

[](https://git-scm.com/docs/git/pt_BR#git-tag) [](https://git-scm.com/docs/git/pt_BR#git-lttaggt)<tag>

uma tag válida _nome_ (por exemplo, uma referência `refs/tags/`_< tag>_).

[](https://git-scm.com/docs/git/pt_BR#git-head) [](https://git-scm.com/docs/git/pt_BR#git-ltheadgt)<head>

um cabeçalho válido _nome_ (por exemplo, uma referência `refs/heads/`_< head>_).
Para obter uma lista mais completa de maneiras de soletrar os nomes dos objetos, consulte a seção "DEFININDO AS REVISÕES" em [gitrevisions[7]](https://git-scm.com/docs/gitrevisions/pt_BR).
##  [](https://git-scm.com/docs/git/pt_BR#_a_estrutura_dos_arquivosdiret%C3%B3rios)A Estrutura dos Arquivos/Diretórios
Favor consultar o documento [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout/pt_BR).
Para mais detalhes sobre cada gancho, consulte [githooks[5]](https://git-scm.com/docs/githooks/pt_BR).
Os SCMs de alto nível podem fornecer e gerenciar informações adicionais no `$GIT_DIR`.
##  [](https://git-scm.com/docs/git/pt_BR#_terminologia)Terminologia
Favor consultar [gitglossary[7]](https://git-scm.com/docs/gitglossary/pt_BR).
##  [](https://git-scm.com/docs/git/pt_BR#_as_vari%C3%A1veis_do_ambiente)As Variáveis do Ambiente
Various Git commands pay attention to environment variables and change their behavior. The environment variables marked as "Boolean" take their values the same way as Boolean valued configuration variables, i.e., "true", "yes", "on" and positive numbers are taken as "yes", while "false", "no", "off", and "0" are taken as "no".
Aqui estão as variáveis:
###  [](https://git-scm.com/docs/git/pt_BR#_system)System

[](https://git-scm.com/docs/git/pt_BR#git-HOME) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeHOMEcodespan)`HOME`

Specifies the path to the user’s home directory. On Windows, if unset, Git will set a process environment variable equal to: `$HOMEDRIVE$HOMEPATH` if both `$HOMEDRIVE` and `$HOMEPATH` exist; otherwise `$USERPROFILE` if `$USERPROFILE` exists.
###  [](https://git-scm.com/docs/git/pt_BR#_o_reposit%C3%B3rio_git)O Repositório Git
Essas variáveis de ambiente se aplicam a _todos_ os comandos principais do Git. Nb: é importante notar que eles podem ser usados/substituídos pelo SCMS acima do Git, portanto, tenha cuidado caso esteja usando um front-end externo.

[](https://git-scm.com/docs/git/pt_BR#git-GITINDEXFILE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITINDEXFILEcodespan)`GIT_INDEX_FILE`

Essa variável de ambiente determina um arquivo alternativo do índice. Caso não seja definido, é utilizado o padrão `$GIT_DIR/index`.

[](https://git-scm.com/docs/git/pt_BR#git-GITINDEXVERSION) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITINDEXVERSIONcodespan)`GIT_INDEX_VERSION`

Esta variável de ambiente especifica qual versão do índice é usada ao gravar o arquivo do índice. Isso não afetará os arquivos existentes no índice. É predefinido que seja usada a versão 2 ou 3 do arquivo do índice. Para mais informações consulte [git-update-index[1]](https://git-scm.com/docs/git-update-index/pt_BR).

[](https://git-scm.com/docs/git/pt_BR#git-GITOBJECTDIRECTORY) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITOBJECTDIRECTORYcodespan)`GIT_OBJECT_DIRECTORY`

Caso o diretório de armazenamento dos objetos seja informado através desta variável de ambiente, os diretórios sha1 serão criados embaixo - caso contrário, o diretório predefinido `$GIT_DIR/objects` será utilizado.

[](https://git-scm.com/docs/git/pt_BR#git-GITALTERNATEOBJECTDIRECTORIES) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITALTERNATEOBJECTDIRECTORIEScodespan)`GIT_ALTERNATE_OBJECT_DIRECTORIES`

Devido à natureza imutável dos objetos Git, os objetos antigos podem ser arquivados em diretórios compartilhados com somente leitura apenas. Esta variável especifica uma lista ":" separada (no Windows ";") dos diretórios dos objetos Git que podem ser utilizados para localizar objetos Git. Os novos objetos não serão gravados nestes diretórios.
As entradas que começam com `"` (aspas duplas) serão interpretadas como caminhos entre as aspas no estilo C, removendo as aspas duplas iniciais e finais, respeitando as escapes da barra invertida. Como por exemplo, o valor _"path-with-\"-and-:-in-it":vanilla-path_ possuí dois caminhos: `path-with-"-and-:-in-it` e `vanilla-path`.

[](https://git-scm.com/docs/git/pt_BR#git-GITDIR) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITDIRcodespan)`GIT_DIR`

Se a variável de ambiente `GIT_DIR` for definida, ela especificará um caminho que será usada para a base do repositório em vez do padrão `.git`. A opção de linha de comando `--git-dir` também define este valor.

[](https://git-scm.com/docs/git/pt_BR#git-GITWORKTREE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITWORKTREEcodespan)`GIT_WORK_TREE`

Defina o caminho para a raiz da árvore de trabalho. Isso também pode ser controlado pela opção de linha de comando `--work-tree` e pela variável de configuração `core.worktree`.

[](https://git-scm.com/docs/git/pt_BR#git-GITNAMESPACE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITNAMESPACEcodespan)`GIT_NAMESPACE`

Defina o espaços de nomes do Git; para mais detalhes consulte [gitnamespaces[7]](https://git-scm.com/docs/gitnamespaces/pt_BR). A opção de linha de comando `--namespace` também define este valor.

[](https://git-scm.com/docs/git/pt_BR#git-GITCEILINGDIRECTORIES) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITCEILINGDIRECTORIEScodespan)`GIT_CEILING_DIRECTORIES`

Essa deve ser uma lista de caminhos absolutos separados por dois-pontos. Se definido, é uma lista de diretórios para os quais o Git não deve fazer um _chdir_ ao procurar pelo diretório do repositório (útil para excluir diretórios de rede com carregamento lento). Ele não excluirá o diretório de trabalho atual ou um `GIT_DIR` definido na linha de comando ou no ambiente. Normalmente, o Git precisa ler os itens dessa lista e resolver qualquer link simbólico que possa estar presente para compará-los com o diretório atual. No entanto, se mesmo esse acesso for lento, você pode adicionar uma entrada vazia à lista para informar ao Git que as entradas subsequentes não são links simbólicos e não precisam ser resolvidas; por exemplo, `GIT_CEILING_DIRECTORIES=/maybe/symlink::/very/slow/non/symlink`.

[](https://git-scm.com/docs/git/pt_BR#git-GITDISCOVERYACROSSFILESYSTEM) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITDISCOVERYACROSSFILESYSTEMcodespan)`GIT_DISCOVERY_ACROSS_FILESYSTEM`

Quando executado num diretório que não tenha um diretório de repositório _.git_ , o Git tenta encontrar esse diretório nos diretórios pai para encontrar o cume da árvore de trabalho, mas, por padrão, ele não cruza os limites do sistema de arquivos. Essa variável de ambiente booleana pode ser definida como _true_ para dizer ao Git para não parar nos limites do sistema de arquivos. Assim como o `GIT_CEILING_DIRECTORIES`, isso não afetará um diretório de repositório explícito definido via `GIT_DIR` ou na linha de comando.

[](https://git-scm.com/docs/git/pt_BR#git-GITCOMMONDIR) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITCOMMONDIRcodespan)`GIT_COMMON_DIR`

Se essa variável estiver definida para um caminho, os arquivos que não são da árvore de trabalho, estão normalmente estão em $GIT_DIR e serão obtidos desse caminho. Os arquivos específicos da árvore de trabalho, como `HEAD` ou índice serão obtidos de $GIT_DIR. Para mais detalhes consulte [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout/pt_BR) e [git-worktree[1]](https://git-scm.com/docs/git-worktree/pt_BR). Essa variável tem precedência mais baixa do que outras variáveis de caminho como `GIT_INDEX_FILE`, `GIT_OBJECT_DIRECTORY`…​

[](https://git-scm.com/docs/git/pt_BR#git-GITDEFAULTHASH) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITDEFAULTHASHcodespan)`GIT_DEFAULT_HASH`

Se essa variável for definida, o algoritmo de hash predefinido para os novos repositórios será definido com este valor. Esse valor é ignorado durante a clonagem e a configuração do repositório remoto é sempre usada. A predefinição é _sha1_. Consulte a opção `--object-format` do comando [git-init[1]](https://git-scm.com/docs/git-init/pt_BR).

[](https://git-scm.com/docs/git/pt_BR#git-GITDEFAULTREFFORMAT) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITDEFAULTREFFORMATcodespan)`GIT_DEFAULT_REF_FORMAT`

Se esta variável for definida, o formato padrão do "backend" de referência para os novos repositórios será definido com esse valor. A predefinição é _files_. Consulte a opção `--ref-format` do comando [git-init[1]](https://git-scm.com/docs/git-init/pt_BR).
###  [](https://git-scm.com/docs/git/pt_BR#_os_commits_do_git)Os Commits do Git

[](https://git-scm.com/docs/git/pt_BR#git-GITAUTHORNAME) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITAUTHORNAMEcodespan)`GIT_AUTHOR_NAME`

O endereço legível do endereço de e-mail utilizado na identidade do autor ao criar os commits, na tag dos objetos ou ao gravar os reflogs. Substitui as definições de configuração `user.name` e `author.name`.

[](https://git-scm.com/docs/git/pt_BR#git-GITAUTHOREMAIL) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITAUTHOREMAILcodespan)`GIT_AUTHOR_EMAIL`

O endereço de email utilizado na identidade do autor ao criar os commits, na marcação dos objetos ou ao gravar os reflogs. Substitui as definições da configuração `user.email` e `author.email`.

[](https://git-scm.com/docs/git/pt_BR#git-GITAUTHORDATE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITAUTHORDATEcodespan)`GIT_AUTHOR_DATE`

A data utilizada para a identidade do autor ao criar objetos commit ou tags ou quando escrever "reflogs". Para conhecer os formatos válidos, consulte [git-commit[1]](https://git-scm.com/docs/git-commit/pt_BR).

[](https://git-scm.com/docs/git/pt_BR#git-GITCOMMITTERNAME) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITCOMMITTERNAMEcodespan)`GIT_COMMITTER_NAME`

O endereço legível do nome utilizado na identidade do autor do commit ao criar os commits, na tag dos objetos ou ao gravar os reflogs. Substitui as definições de configuração `user.name` e `committer.name`.

[](https://git-scm.com/docs/git/pt_BR#git-GITCOMMITTEREMAIL) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITCOMMITTEREMAILcodespan)`GIT_COMMITTER_EMAIL`

O endereço de email utilizado na identidade do autor ao criar os commits, na marcação dos objetos ou ao gravar os reflogs. Overrides the `user.email` and `committer.email` configuration settings.

[](https://git-scm.com/docs/git/pt_BR#git-GITCOMMITTERDATE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITCOMMITTERDATEcodespan)`GIT_COMMITTER_DATE`

A data utilizada para a identidade de quem fez o commit durante a criação dos objetos as tags do commit ou ao gravar os reflogs. Para mais formatos válidos, consulte [git-commit[1]](https://git-scm.com/docs/git-commit/pt_BR).

[](https://git-scm.com/docs/git/pt_BR#git-EMAIL) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeEMAILcodespan)`EMAIL`

O endereço de e-mail usado nas identidades do autor e do commit, caso nenhuma outra variável de ambiente ou da configuração relevante tiver sido definida.
###  [](https://git-scm.com/docs/git/pt_BR#_os_diffs_do_git)Os Diffs do Git

[](https://git-scm.com/docs/git/pt_BR#git-GITDIFFOPTS) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITDIFFOPTScodespan)`GIT_DIFF_OPTS`

A única configuração válida é _--unified=??_ ou _-u??_ para definir a quantidade de linhas de contexto exibidas quando um diff unificado for criado. Isso tem precedência sobre qualquer valor da opção `-U` ou `--unified` usado na linha de comando do Git diff.

[](https://git-scm.com/docs/git/pt_BR#git-GITEXTERNALDIFF) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITEXTERNALDIFFcodespan)`GIT_EXTERNAL_DIFF`

Quando a variável de ambiente `GIT_EXTERNAL_DIFF` é definida, o programa nomeado por ela é invocado para gerar diferenças, e o Git não usa seu mecanismo de diferenças embutido. Para um caminho que for adicionado, removido ou modificado, o `GIT_EXTERNAL_DIFF` é invocado com 7 parâmetros:
```
path old-file old-hex old-mode new-file new-hex new-mode
```

onde:

[](https://git-scm.com/docs/git/pt_BR#git-oldnew-file) [](https://git-scm.com/docs/git/pt_BR#git-ltoldnewgt-file)<old|new>-file

são os arquivos que `GIT_EXTERNAL_DIFF` pode utilizar para ler o conteúdo do <antigo|novo>,

[](https://git-scm.com/docs/git/pt_BR#git-oldnew-hex) [](https://git-scm.com/docs/git/pt_BR#git-ltoldnewgt-hex)<old|new>-hex

são os hashes SHA-1 com 40 hexadecimais,

[](https://git-scm.com/docs/git/pt_BR#git-oldnew-mode) [](https://git-scm.com/docs/git/pt_BR#git-ltoldnewgt-mode)<old|new>-mode

são a representação octais dos modos dos arquivos.
Os parâmetros do arquivo podem apontar para o arquivo de trabalho do usuário (`new-file` em _git-diff-files_ por exemplo), `/dev/null` (`old-file` quando um novo arquivo é adicionado por exemplo) ou um arquivo temporário (`old-file` no índice por exemplo). O `GIT_EXTERNAL_DIFF` não deve se preocupar em desvincular o arquivo temporário - ele é removido quando o `GIT_EXTERNAL_DIFF` for encerrado.
Para um caminho que não foi mesclado, `GIT_EXTERNAL_DIFF` é chamado com 1 parâmetro, <caminho>.
Para cada caminho `GIT_EXTERNAL_DIFF` que é chamado, duas variáveis de ambiente,`GIT_DIFF_PATH_COUNTER` e `GIT_DIFF_PATH_TOTAL` são definidas.

[](https://git-scm.com/docs/git/pt_BR#git-GITEXTERNALDIFFTRUSTEXITCODE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITEXTERNALDIFFTRUSTEXITCODEcodespan)`GIT_EXTERNAL_DIFF_TRUST_EXIT_CODE`

If this Boolean environment variable is set to true then the `GIT_EXTERNAL_DIFF` command is expected to return exit code 0 if it considers the input files to be equal or 1 if it considers them to be different, like `diff`(`1`). If it is set to false, which is the default, then the command is expected to return exit code 0 regardless of equality. Any other exit code causes Git to report a fatal error.

[](https://git-scm.com/docs/git/pt_BR#git-GITDIFFPATHCOUNTER) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITDIFFPATHCOUNTERcodespan)`GIT_DIFF_PATH_COUNTER`

Um contador com base 1 incrementado por um em cada caminho.

[](https://git-scm.com/docs/git/pt_BR#git-GITDIFFPATHTOTAL) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITDIFFPATHTOTALcodespan)`GIT_DIFF_PATH_TOTAL`

A quantidade total dos caminhos.
###  [](https://git-scm.com/docs/git/pt_BR#_outros)Outros

[](https://git-scm.com/docs/git/pt_BR#git-GITMERGEVERBOSITY) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITMERGEVERBOSITYcodespan)`GIT_MERGE_VERBOSITY`

Um número que controla a quantidade de saída exibida pela estratégia de mesclagem recursiva. Substitui o `merge.verbosity`. Consulte o comando [git-merge[1]](https://git-scm.com/docs/git-merge/pt_BR)

[](https://git-scm.com/docs/git/pt_BR#git-GITPAGER) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITPAGERcodespan)`GIT_PAGER`

Esta variável de ambiente substitui a variável `$PAGER`. Se for definido como uma string vazia ou com o valor _cat_ , o Git não iniciará um gerenciador. Consulte também a opção `core.pager` do comando [git-config[1]](https://git-scm.com/docs/git-config/pt_BR).

[](https://git-scm.com/docs/git/pt_BR#git-GITPROGRESSDELAY) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITPROGRESSDELAYcodespan)`GIT_PROGRESS_DELAY`

A number controlling how many seconds to delay before showing optional progress indicators. Defaults to 1.

[](https://git-scm.com/docs/git/pt_BR#git-GITEDITOR) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITEDITORcodespan)`GIT_EDITOR`

Essa variável de ambiente substitui `$EDITOR` e `$VISUAL`. Ele é usado por vários comandos do Git quando, no modo interativo, um editor tiver que ser iniciado. Consulte também [git-var[1]](https://git-scm.com/docs/git-var/pt_BR) e a opção `core.editor` do comando [git-config[1]](https://git-scm.com/docs/git-config/pt_BR).

[](https://git-scm.com/docs/git/pt_BR#git-GITSEQUENCEEDITOR) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITSEQUENCEEDITORcodespan)`GIT_SEQUENCE_EDITOR`

Esta variável de ambiente substitui a configuração do editor do Git ao editar a lista de tarefas de um rebase interativo. Consulte também o comando [git-rebase[1]](https://git-scm.com/docs/git-rebase/pt_BR) e a opção `sequence.editor` em [git-config[1]](https://git-scm.com/docs/git-config/pt_BR).

[](https://git-scm.com/docs/git/pt_BR#git-GITSSH) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITSSHcodespan)`GIT_SSH`


[](https://git-scm.com/docs/git/pt_BR#git-GITSSHCOMMAND) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITSSHCOMMANDcodespan)`GIT_SSH_COMMAND`

Se uma dessas variáveis de ambiente estiver definida, o _git fetch_ e o _git push_ usarão o comando especificado em vez do _ssh_ quando precisarem se conectar a um sistema remoto. Os parâmetros da linha de comando passados para o comando configurado são determinados pela variante ssh. Para mais detalhes consulte a opção `ssh.variant` do comando [git-config[1]](https://git-scm.com/docs/git-config/pt_BR).
O `$GIT_SSH_COMMAND` tem precedência sobre o `$GIT_SSH` e é interpretado pelo shell, o que permite a inclusão de argumentos adicionais. O `$GIT_SSH`, por outro lado, deve ser apenas o caminho para um programa (que pode ser um script de shell de proteção, caso argumentos adicionais sejam necessários).
Normalmente, é mais fácil configurar as opções desejadas através do seu arquivo pessoal `.ssh/config`. Consulte a documentação do ssh para obter mais informações.

[](https://git-scm.com/docs/git/pt_BR#git-GITSSHVARIANT) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITSSHVARIANTcodespan)`GIT_SSH_VARIANT`

Se esta variável de ambiente estiver configurada, ela substitui a detecção automática do Git, caso `GIT_SSH`/`GIT_SSH_COMMAND`/`core.sshCommand` se refere ao OpenSSH, plink ou tortoiseplink. Esta variável substitui a configuração `ssh.variant` que serve ao mesmo propósito.

[](https://git-scm.com/docs/git/pt_BR#git-GITSSLNOVERIFY) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITSSLNOVERIFYcodespan)`GIT_SSL_NO_VERIFY`

Ao definir e exportar essa variável de ambiente para qualquer valor, informa ao Git para não verificar o certificado SSL ao buscar ou enviar via HTTPS.

[](https://git-scm.com/docs/git/pt_BR#git-GITATTRSOURCE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITATTRSOURCEcodespan)`GIT_ATTR_SOURCE`

Define a árvore da qual os gitattributes serão lidos.

[](https://git-scm.com/docs/git/pt_BR#git-GITASKPASS) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITASKPASScodespan)`GIT_ASKPASS`

Se essa variável de ambiente for definida, os comandos do Git que precisarem obter senhas ou frases-senha (por exemplo, para autenticação _HTTP_ ou _IMAP_) invocarão este programa com um prompt adequado como argumento de linha de comando e lerão a senha de seu _STDOUT_. Consulte também a opção `core.askPass` do comando [git-config[1]](https://git-scm.com/docs/git-config/pt_BR).

[](https://git-scm.com/docs/git/pt_BR#git-GITTERMINALPROMPT) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTERMINALPROMPTcodespan)`GIT_TERMINAL_PROMPT`

Caso esta variável de ambiente boleana esteja definida como `false`, o git não será solicitado no terminal (ao solicitar uma autenticação HTTP por exemplo).

[](https://git-scm.com/docs/git/pt_BR#git-GITCONFIGGLOBAL) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITCONFIGGLOBALcodespan)`GIT_CONFIG_GLOBAL`


[](https://git-scm.com/docs/git/pt_BR#git-GITCONFIGSYSTEM) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITCONFIGSYSTEMcodespan)`GIT_CONFIG_SYSTEM`

Obtenha a configuração dos arquivos fornecidos em vez dos arquivos de configuração globais ou em nível de sistema. Se o `GIT_CONFIG_SYSTEM` for definido, o arquivo de configuração do sistema definido no momento da compilação (geralmente `/etc/gitconfig`) não será lido. Da mesma maneira, se o `GIT_CONFIG_GLOBAL` for definido, nem `$HOME/.gitconfig` nem `$XDG_CONFIG_HOME/git/config` serão lidos. Pode ser definido como `/dev/null` para ignorar a leitura de arquivos de configuração do respectivo nível.

[](https://git-scm.com/docs/git/pt_BR#git-GITCONFIGNOSYSTEM) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITCONFIGNOSYSTEMcodespan)`GIT_CONFIG_NOSYSTEM`

Se deve ignorar a leitura das configurações do arquivo `$`(`prefix`)`/etc/gitconfig` de todo o sistema. Esta variável de ambiente booleana pode ser usada junto com `$HOME` e `$XDG_CONFIG_HOME` para criar um ambiente previsível para um script mais exigente, ou você pode defini-la como verdadeira para evitar temporariamente o uso de um arquivo `/etc/gitconfig` com erros enquanto espera que alguém com permissões suficientes o conserte.

[](https://git-scm.com/docs/git/pt_BR#git-GITFLUSH) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITFLUSHcodespan)`GIT_FLUSH`

Se essa variável de ambiente booleana for definida como true, comandos como _git blame_ (no modo incremental), _git rev-list_ , _git log_ , _git check-attr_ e _git check-ignore_ irão impor uma descarga do fluxo de saída após cada registro ter sido descarregado. Se essa variável for definida como _false_ , a saída desses comandos será feita usando a E/S que estiver armazenada no buffer. Se esta variável de ambiente não for definida, o Git escolherá a descarga com o buffer ou orientada a registros com base no fato do stdout parecer estar sendo redirecionado para um arquivo ou não.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACEcodespan)`GIT_TRACE`

Ativa o rastreio geral das mensagens, por exemplo expansão do pseudônimo, execução interna dos comandos e a execução externa dos comandos.
Caso esta variável esteja definida como `1`, `2` ou `true` (a comparação não diferencia as maiúsculas das minúsculas), as mensagens de rastreio serão impressas no stderr.
Caso a variável seja configurada com um valor inteiro maior que 2 e menor que 10 (estritamente), o Git interpretará este valor como um descritor de arquivo aberto e tentará gravar as mensagens de monitoramento neste descritor do arquivo.
Como alternativa, caso a variável estiver definida como um caminho absoluto (começando com um caractere _/_), o Git interpretará isso como um caminho do arquivo e tentará anexar as mensagens de rastreio nelas.
Desativar a variável ou defini-la como vazia _0_ ou _false_ (não faz distinção entre maiúsculas e minúsculas) desativa as mensagens de monitoramento.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACEFSMONITOR) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACEFSMONITORcodespan)`GIT_TRACE_FSMONITOR`

Ativa as mensagens de rastreamento para a extensão do monitor de arquivos do sistema. Consulte o `GIT_TRACE` para consultar as opções de rastreamento disponíveis.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACEPACKACCESS) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACEPACKACCESScodespan)`GIT_TRACE_PACK_ACCESS`

Ativa as mensagens de rastreamento para todos os acessos a qualquer pacote. Para cada acesso, são registrados o nome do arquivo do pacote e o offset. Isso pode ser útil para solucionar alguns problemas de desempenho relacionados ao pacote. Consulte o `GIT_TRACE` para consultar as opções de rastreamento disponíveis.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACEPACKET) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACEPACKETcodespan)`GIT_TRACE_PACKET`

Ativa as mensagens de rastreamento para todos os pacotes que entram ou saem de um determinado programa. Isso pode ajudar a depurar a negociação de objetos ou de outros problemas de protocolo. O rastreamento é desativado num pacote que começa com "PACK" (consulte o `GIT_TRACE_PACKFILE` abaixo). Consulte o `GIT_TRACE` para consultar as opções de rastreamento disponíveis.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACEPACKFILE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACEPACKFILEcodespan)`GIT_TRACE_PACKFILE`

Permite o monitoramento dos arquivos dos pacotes enviados ou recebidos através de um determinado programa. Diferente de outras saídas monitoradas, esse monitoramento é literalmente: sem cabeçalhos e sem a citação dos dados binários. Você quase que certamente vai querer direcionar para um arquivo (`GIT_TRACE_PACKFILE=/tmp/my.pack` por exemplo) em vez de exibi-lo no terminal ou misturá-lo com uma outra saída monitorada.
Observe que atualmente isso é implementado apenas para o lado do cliente dos clones e das buscas.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACEPERFORMANCE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACEPERFORMANCEcodespan)`GIT_TRACE_PERFORMANCE`

Ativa as mensagens de rastreamento relacionadas ao desempenho, como o tempo total de execução de cada comando do Git por exemplo. Consulte o `GIT_TRACE` para consultar as opções de rastreamento disponíveis.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACEREFS) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACEREFScodespan)`GIT_TRACE_REFS`

Ativa as mensagens de rastreamento para as operações no banco de dados de referência. Consulte o `GIT_TRACE` para consultar as opções de rastreamento disponíveis.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACESETUP) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACESETUPcodespan)`GIT_TRACE_SETUP`

Permite que as mensagens de rastreamento imprimam o _.git_ , a árvore de trabalho e o diretório de trabalho atual depois que o Git tiver concluído a sua fase de configuração. Consulte o `GIT_TRACE` para consultar as opções de rastreamento disponíveis.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACESHALLOW) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACESHALLOWcodespan)`GIT_TRACE_SHALLOW`

Ativa asmensagens de rastreamento que possam ajudar a depurar a busca/clonagem dos repositórios rasos. Consulte o `GIT_TRACE` para consultar as opções de rastreamento disponíveis.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACECURL) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACECURLcodespan)`GIT_TRACE_CURL`

Ativa um curl que faz um dump de rastreamento completo de todos os dados da entrada e da saída, incluindo informações descritivas, do protocolo de transporte git. Isso é semelhante a fazer curl `--trace-ascii` na linha de comando. Consulte o `GIT_TRACE` para consultar as opções de rastreamento disponíveis.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACECURLNODATA) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACECURLNODATAcodespan)`GIT_TRACE_CURL_NO_DATA`

Quando um rastreamento curl está ativado (consulte `GIT_TRACE_CURL` acima), não despeje os dados (ou seja, apenas despeje as linhas de informações e os cabeçalhos).

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACE2) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACE2codespan)`GIT_TRACE2`

Ativa as mensagens de rastreamento mais detalhadas da biblioteca "trace2". A saída do `GIT_TRACE2` é um formato simples com base em texto para facilitar a leitura humana.
Caso esta variável esteja definida como `1`, `2` ou `true` (a comparação não diferencia as maiúsculas das minúsculas), as mensagens de rastreio serão impressas no stderr.
Caso a variável seja configurada com um valor inteiro maior que 2 e menor que 10 (estritamente), o Git interpretará este valor como um descritor de arquivo aberto e tentará gravar as mensagens de monitoramento neste descritor do arquivo.
Como alternativa, se a variável for definida como um caminho absoluto (começando com um caractere _/_), o Git interpretará isso como um caminho de arquivo e tentará anexar as mensagens de rastreamento a ele. Se o caminho já existir e for um diretório, as mensagens de rastreamento serão gravadas em arquivos (um por processo) neste diretório, nomeados de acordo com o último componente do SID e um contador opcional (para evitar colisões de nomes de arquivos).
Além disso, se a variável for definida como `af_unix:`[_< tipo-do-soquete>_`:`]_< nome-do-caminho-completo>_, o Git tentará abrir o caminho como um Unix Domain Socket. O tipo de soquete pode ser `stream` ou `dgram`.
Desativar a variável ou defini-la como vazia _0_ ou _false_ (não faz distinção entre maiúsculas e minúsculas) desativa as mensagens de monitoramento.
Para mais detalhes, consulte [Trace2 documentation](https://git-scm.com/docs/api-trace2/pt_BR).

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACE2EVENT) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACE2EVENTcodespan)`GIT_TRACE2_EVENT`

Esta configuração grava um formato baseado em JSON que é adequado para interpretação por máquina. Consulte `GIT_TRACE2` para obter as opções disponíveis de saída do rastreamento e [Documentação do Trace2](https://git-scm.com/docs/api-trace2/pt_BR) para consultar todos os detalhes.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACE2PERF) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACE2PERFcodespan)`GIT_TRACE2_PERF`

Além das mensagens com base em texto disponíveis no `GIT_TRACE2`, esta configuração grava um formato baseado em colunas para entender as regiões de aninhamento. Consulte `GIT_TRACE2` para obter as opções disponíveis de saída do rastreamento e [Documentação do Trace2](https://git-scm.com/docs/api-trace2/pt_BR) para consultar todos os detalhes.

[](https://git-scm.com/docs/git/pt_BR#git-GITTRACEREDACT) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITTRACEREDACTcodespan)`GIT_TRACE_REDACT`

É predefinido que quando o monitoramento seja ativado, o Git redita os valores dos cookies, o cabeçalho "Autorização:" o cabeçalho e o URI do arquivo do pacote "Autorização do proxy:". Defina esta variável de ambiente boleana como `false` para evitar esta redação.

[](https://git-scm.com/docs/git/pt_BR#git-GITNOREPLACEOBJECTS) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITNOREPLACEOBJECTScodespan)`GIT_NO_REPLACE_OBJECTS`

Setting and exporting this environment variable tells Git to ignore replacement refs and do not replace Git objects.

[](https://git-scm.com/docs/git/pt_BR#git-GITLITERALPATHSPECS) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITLITERALPATHSPECScodespan)`GIT_LITERAL_PATHSPECS`

Ao definir essa variável de ambiente boleana como `true` fará com que o Git trate todos os pathspecs de forma literal, e não como padrões glob. Como, por exemplo, a execução do `GIT_LITERAL_PATHSPECS=1` `git` `log` `--` `*.c'` procurará pelos commits que tocam no caminho `*.c` e não nos caminhos que coincidem com o agrupamento `*.c`. Você pode querer isso caso esteja alimentando caminhos literais para o Git (por exemplo, os caminhos informados anteriormente a você pelo `git` `ls-tree`, `--raw`, saída do diff, etc).

[](https://git-scm.com/docs/git/pt_BR#git-GITGLOBPATHSPECS) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITGLOBPATHSPECScodespan)`GIT_GLOB_PATHSPECS`

Ao definir essa variável de ambiente boleana como `true` fará com que o Git trate todos os pathspecs como padrões "glob" (também informados como "glob" mágico).

[](https://git-scm.com/docs/git/pt_BR#git-GITNOGLOBPATHSPECS) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITNOGLOBPATHSPECScodespan)`GIT_NOGLOB_PATHSPECS`

Ao definir essa variável de ambiente boleana como `true` fará com que o Git trate todos os pathspecs como literal (também informados como mágica "literal").

[](https://git-scm.com/docs/git/pt_BR#git-GITICASEPATHSPECS) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITICASEPATHSPECScodespan)`GIT_ICASE_PATHSPECS`

Ao definir essa variável de ambiente boleana como `true` fará com que o Git trate todos os pathspecs como indiferente para maiúsculas e minúsculas.

[](https://git-scm.com/docs/git/pt_BR#git-GITNOLAZYFETCH) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITNOLAZYFETCHcodespan)`GIT_NO_LAZY_FETCH`

Setting this Boolean environment variable to true tells Git not to lazily fetch missing objects from the promisor remote on demand.

[](https://git-scm.com/docs/git/pt_BR#git-GITREFLOGACTION) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITREFLOGACTIONcodespan)`GIT_REFLOG_ACTION`

Quando uma ref é atualizada, são criadas entradas de reflog para manter o controle do motivo pelo qual a ref foi atualizada (que normalmente é o nome do comando de alto nível que atualizou a ref), além dos valores antigos e novos da ref. Um comando porcelana com script pode usar a função auxiliar _set_reflog_action_ no `git-sh-setup` para definir seu nome para essa variável quando for invocado como o comando de nível superior pelo usuário final, a ser registrado no corpo do reflog.

[](https://git-scm.com/docs/git/pt_BR#git-GITREFPARANOIA) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITREFPARANOIAcodespan)`GIT_REF_PARANOIA`

Caso essa variável de ambiente boleana seja definida como `false`, ignore os refs quebrados ou mal nomeados ao iterar sobre as listas dos refs. Normalmente o Git tentará incluir qualquer um desses refs, o que pode causar a falha de algumas operações. Isto normalmente é preferível, já que as operações potencialmente destrutivas (como [git-prune[1]](https://git-scm.com/docs/git-prune/pt_BR)) são melhores abortando em vez de ignorar os refs quebrados (e assim considerando o histórico que eles apontam como não valendo a pena salvar). O valor predefinido é `true` (ou seja, ser paranoico ao detectar e abortar todas as operações). Normalmente não é preciso definir isso como `false`, mas pode ser útil ao tentar salvar os dados de um repositório corrompido.

[](https://git-scm.com/docs/git/pt_BR#git-GITCOMMITGRAPHPARANOIA) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITCOMMITGRAPHPARANOIAcodespan)`GIT_COMMIT_GRAPH_PARANOIA`

Ao carregar um objeto commit do gráfico do _commit-graph_ , o Git executa uma verificação de existência do objeto no banco de dados. Isso é feito para evitar problemas com _commit-graphs_ obsoletos que contêm referências a commits que já foram excluídos, ao custo de uma penalidade no desempenho.
A predefinição é _false_ , que desativa o comportamento mencionado acima. Ativa a verificação de existência para que os commits que estejam desatualizados nunca sejam retornados do _commit-graph_ , ao custo de uma penalidade no desempenho.

[](https://git-scm.com/docs/git/pt_BR#git-GITALLOWPROTOCOL) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITALLOWPROTOCOLcodespan)`GIT_ALLOW_PROTOCOL`

Caso seja definido como uma lista de protocolos separados por dois pontos, comporte-se como se a opção de configuração `protocol.allow` esteja definida como `never`, e cada um dos protocolos listados possua `protocol.`_< nome>_`.allow` definido como `always` (substituindo qualquer configuração já existente). Consulte a descrição do `protocol.allow` no [git-config[1]](https://git-scm.com/docs/git-config/pt_BR) para obter mais detalhes.

[](https://git-scm.com/docs/git/pt_BR#git-GITPROTOCOLFROMUSER) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITPROTOCOLFROMUSERcodespan)`GIT_PROTOCOL_FROM_USER`

Defina esta variável booleana de ambiente como _false_ para evitar que os protocolos usados por `fetch/push/clone` sejam configurados para o estado `user`. Isso é útil para restringir a inicialização recursiva de submódulos a partir de um repositório não confiável ou para programas que alimentam URLS potencialmente não confiáveis para os comandos do git. Para mais detalhes consulte [git-config[1]](https://git-scm.com/docs/git-config/pt_BR).

[](https://git-scm.com/docs/git/pt_BR#git-GITPROTOCOL) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITPROTOCOLcodespan)`GIT_PROTOCOL`

For internal use only. Used in handshaking the wire protocol. Contains a colon _:_ separated list of keys with optional values _< key>[=<value>]_. Presence of unknown keys and values must be ignored.
Observe que os servidores podem precisar ser configurados para permitir que esta variável passe por alguns transportes. Ele será propagado automaticamente ao acessar os repositórios locais (ou seja, `file://` ou um caminho do sistema de arquivos), bem como sobre o protocolo `git://`. Para _git-over-http_ , ele deve funcionar automaticamente na maioria das configurações, porém consulte [git-http-backend[1]](https://git-scm.com/docs/git-http-backend/pt_BR). Para _git-over-ssh_ , o servidor ssh pode precisar ser configurado para permitir que os clientes passem esta variável (por exemplo, usando `AcceptEnv` `GIT_PROTOCOL` com o OpenSSH).
Esta configuração é opcional. Caso a variável não seja propagada, os clientes voltarão ao protocolo "v0" original (mas podem perder algumas melhorias de desempenho ou de recursos). Atualmente esta variável afeta apenas os clones e as buscas (fetch); ainda não é usado para envios "push" (mas pode ser no futuro).

[](https://git-scm.com/docs/git/pt_BR#git-GITOPTIONALLOCKS) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITOPTIONALLOCKScodespan)`GIT_OPTIONAL_LOCKS`

Se essa variável de ambiente booleana for definida como _false_ , o Git concluirá qualquer operação solicitada sem executar nenhuma suboperação opcional que exija um bloqueio. Por exemplo, como um efeito colateral, isso impedirá que o `git` `status` atualize o índice. Isso é útil para processos executados em segundo plano que não queiram causar contenção de bloqueio com outras operações no repositório. A predefinição é `1`.

[](https://git-scm.com/docs/git/pt_BR#git-GITREDIRECTSTDIN) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITREDIRECTSTDINcodespan)`GIT_REDIRECT_STDIN`


[](https://git-scm.com/docs/git/pt_BR#git-GITREDIRECTSTDOUT) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITREDIRECTSTDOUTcodespan)`GIT_REDIRECT_STDOUT`


[](https://git-scm.com/docs/git/pt_BR#git-GITREDIRECTSTDERR) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITREDIRECTSTDERRcodespan)`GIT_REDIRECT_STDERR`

Apenas no Windows: permite redirecionar os identificadores predefinidos de _input/output/error_ para os caminhos definidos através das variáveis do ambiente. Em particular isso é útil nos aplicativos "multi-threaded" onde a maneira canônica de encaminhar os identificadores predefinidos através do `CreateProcess`() não seja uma opção pois exigiria que os identificadores fossem marcados como herdáveis (e consequentemente **todo** processo gerado os herdaria, possivelmente fazendo o bloqueio das operações do Git). A intenção primária de utilização é utilizar os pipes informados para comunicação (_\\\\.\pipe\my-git-stdin-123_ por exemplo).
Dois valores especiais são compatíveis: `off` simplesmente fechará o identificador predefinido correspondente e caso `GIT_REDIRECT_STDERR` seja _2 > & 1_, a predefinição do erro será redirecionado para o mesmo identificador na saída padrão.

[](https://git-scm.com/docs/git/pt_BR#git-GITPRINTSHA1ELLIPSISdescontinuado) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITPRINTSHA1ELLIPSIScodespandescontinuado)`GIT_PRINT_SHA1_ELLIPSIS` (descontinuado)

Se definido como `yes`, imprime uma elipse após um valor SHA-1 (abreviado). Isso afeta as indicações de `HEAD`s desanexados ([git-checkout[1]](https://git-scm.com/docs/git-checkout/pt_BR)) e a criação de um diff puro ([git-diff[1]](https://git-scm.com/docs/git-diff/pt_BR)). A impressão de reticências nos casos mencionados não é mais considerada adequada e o suporte para isso provavelmente será removido num futuro próximo (junto com a variável).

[](https://git-scm.com/docs/git/pt_BR#git-GITADVICE) [](https://git-scm.com/docs/git/pt_BR#git-spanclasssynopsiscodeGITADVICEcodespan)`GIT_ADVICE`

If set to `0`, then disable all advice messages. These messages are intended to provide hints to human users that may help them get out of problematic situations or take advantage of new features. Users can disable individual messages using the `advice.*` config keys. These messages may be disruptive to tools that execute Git processes, so this variable is available to disable the messages. (The `--no-advice` global option is also available, but old Git versions may fail when this option is not understood. The environment variable will be ignored by Git versions that do not understand it.)
##  [](https://git-scm.com/docs/git/pt_BR#_discuss%C3%A3o)Discussão
Mais detalhes estão disponíveis no [capítulo dos conceitos do Git no manual do usuário](https://git-scm.com/docs/user-manual/pt_BR#git-concepts) e [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/pt_BR).
Um projeto Git normalmente consiste num diretório de trabalho com um subdiretório _.git_ no nível mais alto. O diretório _.git_ contém, entre outras coisas, um banco de dados dos objetos compactado que representa o histórico completo do projeto, um arquivo _index_ (índice) que vincula este histórico ao conteúdo atual da árvore de trabalho e os ponteiros nomeados neste histórico, como as etiquetas (tags) e os cabeçalhos da ramificação.
O banco de dados do objeto contém os objetos dos tipos da árvore principal: bolhas, que contêm os dados do arquivo; árvores, que apontam para as bolhas e as outras árvores para criar as hierarquias do diretório; e os commits, cada qual faz referência a uma única árvore e algum número do commit do pai.
O commit, equivalente ao que outros sistemas chamam de _conjunto de alterações_ ou _versão_ , representa uma etapa no histórico do projeto, e cada _ramo principal_ (parent) representa uma etapa imediatamente anterior. Os commits com mais de um ramo principal representam as mesclagens das linhas independentes do desenvolvimento.
Todos os objetos são nomeados pelo hash SHA-1 de seu conteúdo, normalmente escrito como uma cadeia de 40 dígitos hexadecimais. Estes nomes são únicos globalmente. Todo o histórico que leva a um commit pode ser comprovado assinando apenas este commit. Um quarto tipo de objeto, a etiqueta (tag), é fornecida para esta finalidade.
Quando criados pela primeira vez, os objetos são armazenados em arquivos individuais, porém, visando uma maior eficiência, podem ser compactados posteriormente em "pacotes de arquivos".
Os ponteiros mencionados chamados de _refs_ marcam pontos interessantes na história. Uma _ref_ pode conter o nome do SHA-1 de um objeto ou o nome de outra _ref_ (esta última é chamada de "ref simbólica" (symbolic ref)). As _refs_ com nomes que começam com `refs/head/` contêm o nome SHA-1 do commit mais recente (ou cabeçalho _HEAD_) de uma ramificação em desenvolvimento. Os nomes SHA-1 das etiquetas de interesse são armazenados em `refs/tags/`. Uma _ref simbólica_ denominada `HEAD` contém o nome do ramo atualmente submetido ao _check-out_.
O arquivo do índice é inicializado com uma lista de todos os caminhos e, para cada caminho, um objeto bolha (blob) e um conjunto de atributos. O objeto bolha (blob) representa o conteúdo do arquivo a partir do cabeçalho da ramificação atual. Os atributos (hora da última alteração, tamanho, etc.) são obtidos do arquivo correspondente na árvore de trabalho. As alterações subsequentes na árvore de trabalho podem ser encontradas através da comparação destes atributos. O índice pode ser atualizado com um novo conteúdo, e novos commits podem ser criados a partir do conteúdo armazenado no índice.
O índice também é capaz de armazenar várias entradas (chamadas de "stages" ou "estágios") para um determinado nome do caminho. Estes estágios são usados para manter as várias versões não mescladas de um arquivo quando uma mesclagem já estiver em andamento.
##  [](https://git-scm.com/docs/git/pt_BR#_seguran%C3%A7a)SEGURANÇA
Some configuration options and hook files may cause Git to run arbitrary shell commands. Because configuration and hooks are not copied using `git` `clone`, it is generally safe to clone remote repositories with untrusted content, inspect them with `git` `log`, and so on.
However, it is not safe to run Git commands in a `.git` directory (or the working tree that surrounds it) when that `.git` directory itself comes from an untrusted source. The commands in its config and hooks are executed in the usual way.
By default, Git will refuse to run when the repository is owned by someone other than the user running the command. See the entry for `safe.directory` in [git-config[1]](https://git-scm.com/docs/git-config/pt_BR). While this can help protect you in a multi-user environment, note that you can also acquire untrusted repositories that are owned by you (for example, if you extract a zip file or tarball from an untrusted source). In such cases, you’d need to "sanitize" the untrusted repository first.
If you have an untrusted `.git` directory, you should first clone it with `git` `clone` `--no-local` to obtain a clean copy. Git does restrict the set of options and hooks that will be run by `upload-pack`, which handles the server side of a clone or fetch, but beware that the surface area for attack against `upload-pack` is large, so this does carry some risk. The safest thing is to serve the repository as an unprivileged user (either via [git-daemon[1]](https://git-scm.com/docs/git-daemon/pt_BR), ssh, or using other tools to change user ids). See the discussion in the `SECURITY` section of [git-upload-pack[1]](https://git-scm.com/docs/git-upload-pack/pt_BR).
##  [](https://git-scm.com/docs/git/pt_BR#_documenta%C3%A7%C3%A3o_adicional)DOCUMENTAÇÃO ADICIONAL
Consulte as referências na seção "descrição" para começar a usar o Git. Os detalhes a seguir provavelmente são maiores do que o necessário para um usuário iniciante.
O [capítulo de conceitos do Git do manual do usuário](https://git-scm.com/docs/user-manual/pt_BR#git-concepts) e o [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/pt_BR) fornecem introduções à arquitetura subjacente do Git.
Para obter uma visão geral das recomendações do fluxo de trabalho, consulte [gitworkflows[7]](https://git-scm.com/docs/gitworkflows/pt_BR).
Para mais alguns exemplos úteis, consulte também o documento [howto](https://git-scm.com/docs/howto-index/pt_BR).
As entranhas estão documentadas no [Documentação da API do Git](https://git-scm.com/docs/api-index/pt_BR).
Os usuários que estiverem migrando do CVS também podem querer ler [gitcvs-migration[7]](https://git-scm.com/docs/gitcvs-migration/pt_BR).
##  [](https://git-scm.com/docs/git/pt_BR#_autores)Autores
O Git foi criado por Linus Torvalds e atualmente é mantido por Junio C Hamano. Várias contribuições vieram da lista de discussão do Git <git@vger.kernel.org>. O site <https://openhub.net/p/git/contributors/summary> fornece uma lista mais completa dos colaboradores.
Caso tenha um clone do _git.git_ , a saída do [git-shortlog[1]](https://git-scm.com/docs/git-shortlog/pt_BR) e do [git-blame[1]](https://git-scm.com/docs/git-blame/pt_BR) pode exibir os autores para as partes específicas do projeto.
##  [](https://git-scm.com/docs/git/pt_BR#_reportando_um_erro)Reportando um Erro
Relate os erros na lista de discussão do Git <git@vger.kernel.org>, onde o desenvolvimento principal e a manutenção são feitas. Não é necessário estar inscrito na lista para enviar uma mensagem para lá. Consulte o arquivo da lista em <https://lore.kernel.org/git> para ver relatórios de erros anteriores além de outras discussões.
Os problemas relevantes para a segurança devem ser divulgadas em particular na mailing list do Git Security <git-security@googlegroups.com>.
##  [](https://git-scm.com/docs/git/pt_BR#_veja_tamb%C3%A9m)VEJA TAMBÉM
[gittutorial[7]](https://git-scm.com/docs/gittutorial/pt_BR), [gittutorial-2[7]](https://git-scm.com/docs/gittutorial-2/pt_BR), [giteveryday[7]](https://git-scm.com/docs/giteveryday/pt_BR), [gitcvs-migration[7]](https://git-scm.com/docs/gitcvs-migration/pt_BR), [gitglossary[7]](https://git-scm.com/docs/gitglossary/pt_BR), [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/pt_BR), [gitcli[7]](https://git-scm.com/docs/gitcli/pt_BR), [O Manual do Usuário do Git](https://git-scm.com/docs/user-manual/pt_BR), [gitworkflows[7]](https://git-scm.com/docs/gitworkflows/pt_BR)
##  [](https://git-scm.com/docs/git/pt_BR#_git)GIT
Parte do conjunto [git[1]](https://git-scm.com/docs/git/pt_BR)
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
